==> lightdash_client_python-0.621.0.tar.gz: lightdash_client_python-0.621.0/lightdash_client/models/pick_create_postgres_credentials_exclude_keyof_create_postgres_credentials_sensitive_credentials_field_names_start_of_week.py <==
from typing import Any
from typing import Dict
from typing import List
from typing import Type
from typing import TypeVar

import attr

T = TypeVar(
    "T",
    bound="PickCreatePostgresCredentialsExcludeKeyofCreatePostgresCredentialsSensitiveCredentialsFieldNamesStartOfWeek",
)


@attr.s(auto_attribs=True)
class PickCreatePostgresCredentialsExcludeKeyofCreatePostgresCredentialsSensitiveCredentialsFieldNamesStartOfWeek:
    """ """

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        pick_create_postgres_credentials_exclude_keyof_create_postgres_credentials_sensitive_credentials_field_names_start_of_week = (
            cls()
        )

        pick_create_postgres_credentials_exclude_keyof_create_postgres_credentials_sensitive_credentials_field_names_start_of_week.additional_properties = (
            d
        )
        return pick_create_postgres_credentials_exclude_keyof_create_postgres_credentials_sensitive_credentials_field_names_start_of_week

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> lightdash_client_python-0.692.1.tar.gz: lightdash_client_python-0.692.1/lightdash_client/models/pick_create_postgres_credentials_exclude_keyof_create_postgres_credentials_sensitive_credentials_field_names_start_of_week.py <==
from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar(
    "T",
    bound="PickCreatePostgresCredentialsExcludeKeyofCreatePostgresCredentialsSensitiveCredentialsFieldNamesStartOfWeek",
)


@attr.s(auto_attribs=True)
class PickCreatePostgresCredentialsExcludeKeyofCreatePostgresCredentialsSensitiveCredentialsFieldNamesStartOfWeek:
    """ """

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        pick_create_postgres_credentials_exclude_keyof_create_postgres_credentials_sensitive_credentials_field_names_start_of_week = (
            cls()
        )

        pick_create_postgres_credentials_exclude_keyof_create_postgres_credentials_sensitive_credentials_field_names_start_of_week.additional_properties = (
            d
        )
        return pick_create_postgres_credentials_exclude_keyof_create_postgres_credentials_sensitive_credentials_field_names_start_of_week

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
